@@ -4,9 +4,6 @@
 //
 //   (C) Copyright 2002-2005, 2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rivendell_filter.h,v 1.1 2008/07/18 05:08:18 fredg Exp $
-//      $Date: 2008/07/18 05:08:18 $
-//
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
 //   published by the Free Software Foundation.
@@ -36,7 +33,7 @@ class MainObject : public QObject
 {
   Q_OBJECT
  public:
-  MainObject(QObject *parent=0,const char *name=0);
+  MainObject(QObject *parent=0);
 };
 
 
