@@ -2,9 +2,7 @@
 //
 // Edit a SoundPanel Panel Name
 //
-//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdedit_panel_name.h,v 1.1 2007/07/09 15:47:09 fredg Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,15 +21,15 @@
 #ifndef RDEDIT_PANEL_NAME_H
 #define RDEDIT_PANEL_NAME_H
 
-#include <qdialog.h>
 #include <qlineedit.h>
 
+#include <rddialog.h>
 
-class RDEditPanelName : public QDialog
+class RDEditPanelName : public RDDialog
 {
   Q_OBJECT
  public:
-  RDEditPanelName(QString *panelname,QWidget *parent=0,const char *name=0);
+  RDEditPanelName(QString *panelname,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
   
