@@ -2,7 +2,7 @@
 //
 // Add a Rivendell User
 //
-//   (C) Copyright 2002,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,17 +21,17 @@
 #ifndef ADD_USER_H
 #define ADD_USER_H
 
-#include <qdialog.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
+#include <q3listbox.h>
+#include <q3textedit.h>
 #include <qpixmap.h>
 #include <qcheckbox.h>
 #include <qsqldatabase.h>
 #include <qlineedit.h>
 
+#include <rddialog.h>
 #include <rduser.h>
 
-class AddUser : public QDialog
+class AddUser : public RDDialog
 {
   Q_OBJECT
   public:
