@@ -2,9 +2,7 @@
 //
 // List Rivendell Dropbox Configurations
 //
-//   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: list_dropboxes.h,v 1.2 2007-10-05 13:50:32 fredg Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,22 +21,17 @@
 #ifndef LIST_DROPBOXES_H
 #define LIST_DROPBOXES_H
 
-#include <qdialog.h>
-#include <qpixmap.h>
-#include <qradiobutton.h>
-#include <qsqldatabase.h>
 #include <qpushbutton.h>
 
-#include <rdlistviewitem.h>
 #include <rddb.h>
+#include <rddialog.h>
+#include <rdlistviewitem.h>
 
-
-class ListDropboxes : public QDialog
+class ListDropboxes : public RDDialog
 {
   Q_OBJECT
  public:
-  ListDropboxes(const QString &stationname,
-		QWidget *parent=0,const char *name=0);
+  ListDropboxes(const QString &stationname,QWidget *parent=0);
   ~ListDropboxes();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -46,8 +39,9 @@ class ListDropboxes : public QDialog
  private slots:
   void addData();
   void editData();
+  void duplicateData();
   void deleteData();
-  void doubleClickedData(QListViewItem *item,const QPoint &pt,int col);
+  void doubleClickedData(Q3ListViewItem *item,const QPoint &pt,int col);
   void closeData();
 
  protected:
@@ -60,6 +54,7 @@ class ListDropboxes : public QDialog
   RDListView *list_dropboxes_view;
   QPushButton *list_add_button;
   QPushButton *list_edit_button;
+  QPushButton *list_duplicate_button;
   QPushButton *list_delete_button;
   QPushButton *list_close_button;
   QString list_stationname;
