@@ -2,7 +2,7 @@
 //
 // List Rivendell Reports
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,14 +21,14 @@
 #ifndef LIST_REPORTS_H
 #define LIST_REPORTS_H
 
-#include <qdialog.h>
-#include <qlistbox.h>
-#include <qtextedit.h>
-#include <qpixmap.h>
-#include <qradiobutton.h>
-#include <qsqldatabase.h>
+#include <q3listbox.h>
 
-class ListReports : public QDialog
+#include <qlabel.h>
+#include <qpushbutton.h>
+
+#include <rddialog.h>
+
+class ListReports : public RDDialog
 {
   Q_OBJECT
   public:
@@ -41,16 +41,22 @@ class ListReports : public QDialog
    void addData();
    void editData();
    void deleteData();
-   void doubleClickedData(QListBoxItem *item);
+   void doubleClickedData(Q3ListBoxItem *item);
    void closeData();
 
-  private:
-   void DeleteReport(QString rptname);
-   void RefreshList(QString rptname="");
-   QListBox *list_box;
+ protected:
+  void resizeEvent(QResizeEvent *e);
+
+ private:
+  void DeleteReport(QString rptname);
+  void RefreshList(QString rptname="");
+  QLabel *list_title_label;
+  Q3ListBox *list_box;
+  QPushButton *list_add_button;
+  QPushButton *list_edit_button;
+  QPushButton *list_delete_button;
+  QPushButton *list_close_button;
 };
 
 
-#endif
-
-
+#endif  // LIST_REPORTS_H
