@@ -3,6 +3,7 @@
 // The scheduler codes dialog for rdadmin
 //
 //   Stefan Gabriel <stg@st-gabriel.de>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsyustems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,49 +19,34 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qdialog.h>
-#include <qstring.h>
-#include <qpushbutton.h>
-#include <qlistbox.h>
-#include <qlabel.h>
-#include <qpainter.h>
-#include <qevent.h>
 #include <qmessagebox.h>
-#include <qbuttongroup.h>
 
-#include <rddb.h>
 #include <rdcart.h>
+#include <rddb.h>
 #include <rdescape_string.h>
 #include <rdtextfile.h>
 
-#include <edit_schedcodes.h>
-#include <add_schedcodes.h>
-#include <list_schedcodes.h>
+#include "add_schedcodes.h"
+#include "edit_schedcodes.h"
+#include "list_schedcodes.h"
 
 ListSchedCodes::ListSchedCodes(QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
+  setModal(true);
+
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
+  setMinimumSize(sizeHint());
 
-  setCaption(tr("Rivendell Scheduler Codes List"));
-
-  //
-  // Create Fonts
-  //
-  QFont font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-  QFont small_font=QFont("Helvetica",10,QFont::Normal);
-  small_font.setPixelSize(10);
+  setWindowTitle("RDAdmin  - "+tr("Rivendell Scheduler Codes List"));
 
   //
   //  Add Button
   //
   list_add_button=new QPushButton(this);
-  list_add_button->setFont(font);
+  list_add_button->setFont(buttonFont());
   list_add_button->setText(tr("&Add"));
   connect(list_add_button,SIGNAL(clicked()),this,SLOT(addData()));
 
@@ -68,7 +54,7 @@ ListSchedCodes::ListSchedCodes(QWidget *parent)
   //  Edit Button
   //
   list_edit_button=new QPushButton(this);
-  list_edit_button->setFont(font);
+  list_edit_button->setFont(buttonFont());
   list_edit_button->setText(tr("&Edit"));
   connect(list_edit_button,SIGNAL(clicked()),this,SLOT(editData()));
 
@@ -76,7 +62,7 @@ ListSchedCodes::ListSchedCodes(QWidget *parent)
   //  Delete Button
   //
   list_delete_button=new QPushButton(this);
-  list_delete_button->setFont(font);
+  list_delete_button->setFont(buttonFont());
   list_delete_button->setText(tr("&Delete"));
   connect(list_delete_button,SIGNAL(clicked()),this,SLOT(deleteData()));
 
@@ -85,25 +71,25 @@ ListSchedCodes::ListSchedCodes(QWidget *parent)
   //
   list_close_button=new QPushButton(this);
   list_close_button->setDefault(true);
-  list_close_button->setFont(font);
+  list_close_button->setFont(buttonFont());
   list_close_button->setText(tr("&Close"));
   connect(list_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
   //
   // Group List
   //
-  list_schedCodes_view=new QListView(this);
+  list_schedCodes_view=new Q3ListView(this);
   list_schedCodes_view->setAllColumnsShowFocus(true);
   list_schedCodes_view->addColumn(tr("CODE"));
   list_schedCodes_view->addColumn(tr("DESCRIPTION"));
   QLabel *list_box_label=
     new QLabel(list_schedCodes_view,tr("Scheduler Codes:"),this);
-  list_box_label->setFont(font);
+  list_box_label->setFont(buttonFont());
   list_box_label->setGeometry(14,11,200,19);
   connect(list_schedCodes_view,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
 	  this,
-	  SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
+	  SLOT(doubleClickedData(Q3ListViewItem *,const QPoint &,int)));
 
   RefreshList();
 }
@@ -137,7 +123,7 @@ void ListSchedCodes::addData()
   }
   delete add_schedCode;
   add_schedCode=NULL;
-  QListViewItem *item=new QListViewItem(list_schedCodes_view);
+  Q3ListViewItem *item=new Q3ListViewItem(list_schedCodes_view);
   item->setText(0,schedCode);
   RefreshItem(item);
   item->setSelected(true);
@@ -148,7 +134,7 @@ void ListSchedCodes::addData()
 
 void ListSchedCodes::editData()
 {
-  QListViewItem *item=list_schedCodes_view->selectedItem();
+  Q3ListViewItem *item=list_schedCodes_view->selectedItem();
   if(item==NULL) {
     return;
   }
@@ -163,7 +149,7 @@ void ListSchedCodes::editData()
 
 void ListSchedCodes::deleteData()
 {
-  QListViewItem *item=list_schedCodes_view->selectedItem();
+  Q3ListViewItem *item=list_schedCodes_view->selectedItem();
   if(item==NULL) {
     return;
   }
@@ -200,7 +186,7 @@ void ListSchedCodes::deleteData()
 }
 
 
-void ListSchedCodes::doubleClickedData(QListViewItem *item,const QPoint &pt,
+void ListSchedCodes::doubleClickedData(Q3ListViewItem *item,const QPoint &pt,
 				   int col)
 {
   editData();
@@ -227,19 +213,19 @@ void ListSchedCodes::RefreshList()
 {
   QString sql;
   RDSqlQuery *q;
-  QListViewItem *item;
+  Q3ListViewItem *item;
 
   list_schedCodes_view->clear();
-  q=new RDSqlQuery("select CODE,DESCRIPTION from SCHED_CODES",0);
+  q=new RDSqlQuery("select CODE,DESCRIPTION from SCHED_CODES");
   while (q->next()) {
-    item=new QListViewItem(list_schedCodes_view);
+    item=new Q3ListViewItem(list_schedCodes_view);
     WriteItem(item,q);
   }
   delete q;
 }
 
 
-void ListSchedCodes::RefreshItem(QListViewItem *item)
+void ListSchedCodes::RefreshItem(Q3ListViewItem *item)
 {
   QString sql;
   RDSqlQuery *q;
@@ -254,7 +240,7 @@ void ListSchedCodes::RefreshItem(QListViewItem *item)
 }
 
 
-void ListSchedCodes::WriteItem(QListViewItem *item,RDSqlQuery *q)
+void ListSchedCodes::WriteItem(Q3ListViewItem *item,RDSqlQuery *q)
 {
   item->setText(0,q->value(0).toString());
   item->setText(1,q->value(1).toString());
