@@ -2,7 +2,7 @@
 //
 // Select a Rivendell Log
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,87 +22,82 @@
 #include <qpushbutton.h>
 
 #include <rdadd_log.h>
+#include <rdapplication.h>
 #include <rddb.h>
 #include <rdescape_string.h>
 
-#include <globals.h>
-#include <list_logs.h>
+#include "globals.h"
+#include "list_logs.h"
 
-ListLogs::ListLogs(LogPlay *log,QWidget *parent)
-  : QDialog(parent,"",true)
+ListLogs::ListLogs(RDLogPlay *log,QWidget *parent)
+  : RDDialog(parent)
 {
   //
   // Fix the Window Size
   //
   setMinimumSize(sizeHint());
 
-  //
-  // Generate Fonts
-  //
-  QFont button_font("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-
   list_log=log;
-  setCaption(tr("Select Log"));
+  setWindowTitle("RDAirPlay - "+tr("Select Log"));
 
   //
   // Filter Widget
   //
   list_filter_widget=
-    new RDLogFilter(RDLogFilter::StationFilter,rduser,air_config,this);
+    new RDLogFilter(RDLogFilter::StationFilter,this);
   connect(list_filter_widget,SIGNAL(filterChanged(const QString &)),
 	  this,SLOT(filterChangedData(const QString &)));
 
   //
   // Log List
   //
-  list_log_list=new QListView(this);
+  list_log_list=new Q3ListView(this);
   list_log_list->setAllColumnsShowFocus(true);
   list_log_list->setItemMargin(5);
   connect(list_log_list,
-          SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+          SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
           this,
-          SLOT(doubleClickedData(QListViewItem *,const QPoint &,int)));
-  list_log_list->addColumn(tr("NAME"));
+          SLOT(doubleClickedData(Q3ListViewItem *,const QPoint &,int)));
+  list_log_list->addColumn(tr("Name"));
   list_log_list->setColumnAlignment(0,Qt::AlignLeft);
-  list_log_list->addColumn(tr("DESCRIPTION"));
+  list_log_list->addColumn(tr("Description"));
   list_log_list->setColumnAlignment(1,Qt::AlignLeft);
-  list_log_list->addColumn(tr("SERVICE"));
+  list_log_list->addColumn(tr("Service"));
   list_log_list->setColumnAlignment(2,Qt::AlignLeft);
 
   //
   // Load Button
   //
   list_load_button=new QPushButton(tr("Load"),this);
-  list_load_button->setFont(button_font);
+  list_load_button->setFont(buttonFont());
   connect(list_load_button,SIGNAL(clicked()),this,SLOT(loadButtonData()));
 
   //
   // Unload Button
   //
   list_unload_button=new QPushButton(tr("Unload"),this);
-  list_unload_button->setFont(button_font);
+  list_unload_button->setFont(buttonFont());
   connect(list_unload_button,SIGNAL(clicked()),this,SLOT(unloadButtonData()));
 
   //
   // Save Button
   //
   list_save_button=new QPushButton(tr("Save"),this);
-  list_save_button->setFont(button_font);
+  list_save_button->setFont(buttonFont());
   connect(list_save_button,SIGNAL(clicked()),this,SLOT(saveButtonData()));
 
   //
   // Save As Button
   //
   list_saveas_button=new QPushButton(tr("Save As"),this);
-  list_saveas_button->setFont(button_font);
+  list_saveas_button->setFont(buttonFont());
   connect(list_saveas_button,SIGNAL(clicked()),this,SLOT(saveAsButtonData()));
 
   //
   // Cancel Button
   //
   list_cancel_button=new QPushButton(tr("Cancel"),this);
-  list_cancel_button->setFont(button_font);
+  list_cancel_button->setFont(buttonFont());
   list_cancel_button->setDefault(true);
   connect(list_cancel_button,SIGNAL(clicked()),this,SLOT(cancelButtonData()));
 
@@ -127,10 +122,10 @@ int ListLogs::exec(QString *logname,QString *svcname,RDLogLock **log_lock)
   list_logname=logname;
   list_svcname=svcname;
   list_log_lock=log_lock;
-  list_saveas_button->setEnabled(rduser->createLog());
+  list_saveas_button->setEnabled(rda->user()->createLog());
   QStringList services_list;
   QString sql=QString("select SERVICE_NAME from SERVICE_PERMS where ")+
-    "STATION_NAME=\""+RDEscapeString(rdstation_conf->name())+"\"";
+    "STATION_NAME=\""+RDEscapeString(rda->station()->name())+"\"";
   RDSqlQuery *q=new RDSqlQuery(sql);
   services_list.push_back(tr("ALL"));
   while(q->next()) {
@@ -155,7 +150,7 @@ void ListLogs::closeEvent(QCloseEvent *e)
 }
 
 
-void ListLogs::doubleClickedData(QListViewItem *,const QPoint &,int)
+void ListLogs::doubleClickedData(Q3ListViewItem *,const QPoint &,int)
 {
   loadButtonData();
 }
@@ -163,7 +158,7 @@ void ListLogs::doubleClickedData(QListViewItem *,const QPoint &,int)
 
 void ListLogs::loadButtonData()
 {
-  QListViewItem *item=list_log_list->selectedItem();
+  Q3ListViewItem *item=list_log_list->selectedItem();
   if(item==NULL) {
     return;
   }
@@ -179,7 +174,7 @@ void ListLogs::saveButtonData()
     saveAsButtonData();
   }
   else {
-    *list_log_lock=new RDLogLock(*list_logname,rduser,rdstation_conf,this);
+    *list_log_lock=new RDLogLock(*list_logname,rda->user(),rda->station(),this);
     if(!TryLock(*list_log_lock)) {
       delete *list_log_lock;
       *list_log_lock=NULL;
@@ -202,8 +197,8 @@ void ListLogs::saveAsButtonData()
   QString logname;
   QString svcname=*list_svcname;
   RDAddLog *log;
-  log=new RDAddLog(&logname,&svcname,RDLogFilter::StationFilter,rduser,
-		   rdstation_conf,tr("Rename Log"),this);
+  log=new RDAddLog(&logname,&svcname,RDLogFilter::StationFilter,
+		   tr("Rename Log"),this);
   if(log->exec()<0) {
     delete log;
     return;
@@ -246,7 +241,7 @@ void ListLogs::RefreshList()
 {
   RDSqlQuery *q;
   QString sql;
-  QListViewItem *l;
+  Q3ListViewItem *l;
   QDate current_date=QDate::currentDate();
   QStringList services_list;
 
@@ -262,7 +257,7 @@ void ListLogs::RefreshList()
     list_filter_widget->whereSql();
   q=new RDSqlQuery(sql);
   while(q->next()) {
-    l=new QListViewItem(list_log_list);
+    l=new Q3ListViewItem(list_log_list);
     l->setText(0,q->value(0).toString());
     l->setText(1,q->value(1).toString());
     l->setText(2,q->value(2).toString());
