@@ -2,9 +2,7 @@
 //
 // The post counter widget for Rivendell
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: stop_counter.h,v 1.8 2007/02/14 21:53:27 fredg Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,16 +21,14 @@
 #ifndef STOP_COUNTER_H
 #define STOP_COUNTER_H
 
-#include <qpushbutton.h>
-#include <qdatetime.h>
-#include <qlabel.h>
 #include <rdairplay_conf.h>
+#include <rdpushbutton.h>
 
-class StopCounter : public QPushButton
+class StopCounter : public RDPushButton
 {
  Q_OBJECT
  public:
-  StopCounter(QWidget *parent=0,const char *name=0);
+  StopCounter(QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
   void setState(bool state);
@@ -48,10 +44,8 @@ class StopCounter : public QPushButton
   bool stop_running;
   bool old_stop_running;
   int old_msecs;
-  QFont stop_time_font;
-  QFont stop_text_font;
   QString stop_text;
   QString time_format;
 };
 
-#endif
+#endif  // STOP_COUNTER_H
