@@ -303,7 +303,7 @@ Do you still want to delete?</source>
     </message>
     <message>
         <source>Apply FreeDB Values to Cart</source>
-        <translation>Aplicar Valores do FreeDB ao Cartão</translation>
+        <translation type="obsolete">Aplicar Valores do FreeDB ao Cartão</translation>
     </message>
     <message>
         <source>Tracks</source>
@@ -442,14 +442,6 @@ Rip</source>
         <source>[none]</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Ripper Error</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to create temporary directory!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Rip CD</source>
         <translation type="unfinished">Extrair CD</translation>
@@ -459,6 +451,22 @@ Rip</source>
 Track</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Values to Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lookup Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskGauge</name>
@@ -487,7 +495,7 @@ Track</source>
     </message>
     <message>
         <source>Apply FreeDB Values to Carts</source>
-        <translation>Aplicar Valores do FreeDB ao Cartão</translation>
+        <translation type="obsolete">Aplicar Valores do FreeDB ao Cartão</translation>
     </message>
     <message>
         <source>Tracks</source>
@@ -680,14 +688,6 @@ Disk</source>
         <source>RDLibrary - Ripper Error</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Ripper Error</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to create temporary directory!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Track</source>
         <translation type="unfinished"></translation>
@@ -733,6 +733,18 @@ Selection</source>
         <source>Unable to allocate cart in group</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Values to Carts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lookup Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditCart</name>
