@@ -2,9 +2,7 @@
 //
 // Global Variable Declarations for RDLogManager
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: globals.h,v 1.7 2011/06/21 22:20:44 cvs Exp $
+//   (C) Copyright 2002-2004,2016-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,20 +21,12 @@
 #ifndef GLOBALS_H
 #define GLOBALS_H
 
-#include <rdstation.h>
-#include <rduser.h>
-#include <rdripc.h>
-#include <rdcae.h>
-
 //
 // Global Resources
 //
-extern RDStation *rdstation_conf;
-extern RDUser *rduser;
-extern RDRipc *rdripc;
-extern RDCae *rdcae;
 extern QString *event_filter;
 extern QString *clock_filter;
 extern bool skip_db_check;
 
+
 #endif  // GLOBALS_H
