@@ -2,9 +2,7 @@
 //
 // Select a Set of Dates for a Rivendell Report
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: pick_report_dates.h,v 1.3 2007/02/14 21:57:04 fredg Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,18 +21,18 @@
 #ifndef PICK_REPORT_DATE_H
 #define PICK_REPORT_DATE_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
 #include <qcombobox.h>
 #include <qdatetimeedit.h>
 
+#include <rddialog.h>
 
-class PickReportDates : public QDialog
+#include "viewreportdialog.h"
+
+class PickReportDates : public RDDialog
 {
   Q_OBJECT
  public:
-  PickReportDates(const QString &svcname,
-		    QWidget *parent=0,const char *name=0);
+  PickReportDates(const QString &svcname,QWidget *parent=0);
   ~PickReportDates();
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
@@ -50,6 +48,7 @@ class PickReportDates : public QDialog
   QDateEdit *edit_startdate_edit;
   QDateEdit *edit_enddate_edit;
   QString edit_svcname;
+  ViewReportDialog *edit_viewreport_dialog;
 };
 
 
