@@ -1012,14 +1012,6 @@ Opětovné sloučení tato data smaže. Sloučit znovu?</translation>
         <source>Unable to clear music links</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unable to link music log</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to link traffic log</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Generate Log</source>
         <translation type="unfinished"></translation>
@@ -1064,6 +1056,18 @@ Opětovné sloučení tato data smaže. Sloučit znovu?</translation>
         <source>No broken rules or validation exceptions found.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RDLogManager Error Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music schedule import failed!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Traffic schedule import failed!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImportListView</name>
