@@ -2,9 +2,7 @@
 //
 // Rename an RDLogManager Event or Clock
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rename_item.h,v 1.5 2010/07/29 19:32:37 cvs Exp $
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,16 +21,16 @@
 #ifndef RENAME_ITEM_H
 #define RENAME_ITEM_H
 
-#include <qdialog.h>
-#include <qpushbutton.h>
 #include <qlineedit.h>
+#include <qpushbutton.h>
 
+#include <rddialog.h>
 
-class RenameItem : public QDialog
+class RenameItem : public RDDialog
 {
  Q_OBJECT
  public:
-  RenameItem(QString *text,QString table,QWidget *parent=0,const char *name=0);
+  RenameItem(QString *text,QString table,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
