@@ -2,9 +2,7 @@
 //
 // A Rivendell switcher driver for the BroadcastTools SRC-8 III
 //
-//   (C) Copyright 2002-2005,2010 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: btsrc8iii.h,v 1.3 2010/08/03 23:39:25 cvs Exp $
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,14 +30,13 @@
 #include <switcher.h>
 
 #define BTSRC8III_UNIT_ID 0
-#define BTSRC8III_POLL_INTERVAL 100
 #define BTSRC8III_GPIO_PINS 8
 
 class BtSrc8Iii : public Switcher
 {
  Q_OBJECT
  public:
-  BtSrc8Iii(RDMatrix *matrix,QObject *parent=0,const char *name=0);
+  BtSrc8Iii(RDMatrix *matrix,QObject *parent=0);
   ~BtSrc8Iii();
   RDMatrix::Type type();
   unsigned gpiQuantity();
@@ -50,8 +47,8 @@ class BtSrc8Iii : public Switcher
 
  private slots:
   void processStatus();
-  void gpiOneshotData(void *data);
-  void gpoOneshotData(void *data);
+  void gpiOneshotData(int value);
+  void gpoOneshotData(int value);
 
  private:
   RDTTYDevice *bt_device;
