@@ -2,7 +2,7 @@
 //
 // A Rivendell LWRP audio switcher driver for LiveWire networks.
 //
-//   (C) Copyright 2002-2013,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,9 +19,14 @@
 //
 
 #include <stdlib.h>
+#include <syslog.h>
+
+#include <rdapplication.h>
 #include <rddb.h>
-#include <globals.h>
-#include <livewire_lwrpaudio.h>
+#include <rdescape_string.h>
+
+#include "globals.h"
+#include "livewire_lwrpaudio.h"
 
 LiveWireLwrpAudio::LiveWireLwrpAudio(RDMatrix *matrix,QObject *parent)
   : Switcher(matrix,parent)
@@ -32,16 +37,20 @@ LiveWireLwrpAudio::LiveWireLwrpAudio(RDMatrix *matrix,QObject *parent)
   //
   // Get Matrix Parameters
   //
-  livewire_stationname=rdstation->name();
+  livewire_stationname=rda->station()->name();
   livewire_matrix=matrix->matrix();
 
   //
   // Load The Node List
   //
-  sql=QString().sprintf("select HOSTNAME,TCP_PORT,PASSWORD,BASE_OUTPUT \
-                         from SWITCHER_NODES where (STATION_NAME=\"%s\")&&\
-                         (MATRIX=%d)",(const char *)livewire_stationname,
-			livewire_matrix);
+  sql=QString("select ")+
+    "HOSTNAME,"+     // 00
+    "TCP_PORT,"+     // 01
+    "PASSWORD,"+     // 02
+    "BASE_OUTPUT "+  // 03
+    "from SWITCHER_NODES where "+
+    "(STATION_NAME=\""+RDEscapeString(livewire_stationname)+"\")&&"+
+    QString().sprintf("(MATRIX=%d)",livewire_matrix);
   q=new RDSqlQuery(sql);
   while(q->next()) {
     livewire_nodes.push_back(new RDLiveWire(livewire_nodes.size(),this));
@@ -55,20 +64,6 @@ LiveWireLwrpAudio::LiveWireLwrpAudio(RDMatrix *matrix,QObject *parent)
 	    SIGNAL(destinationChanged(unsigned,RDLiveWireDestination *)),
 	    this,
 	    SLOT(destinationChangedData(unsigned,RDLiveWireDestination *)));
-    /*
-    connect(livewire_nodes.back(),
-	    SIGNAL(gpoConfigChanged(unsigned,unsigned,unsigned)),
-	    this,
-	    SLOT(gpoConfigChangedData(unsigned,unsigned,unsigned)));
-    connect(livewire_nodes.back(),
-	    SIGNAL(gpiChanged(unsigned,unsigned,unsigned,bool)),
-	    this,
-	    SLOT(gpiChangedData(unsigned,unsigned,unsigned,bool)));
-    connect(livewire_nodes.back(),
-	    SIGNAL(gpoChanged(unsigned,unsigned,unsigned,bool)),
-	    this,
-	    SLOT(gpoChangedData(unsigned,unsigned,unsigned,bool)));
-    */
     connect(livewire_nodes.back(),
 	    SIGNAL(watchdogStateChanged(unsigned,const QString &)),
 	    this,SLOT(watchdogStateChangedData(unsigned,const QString &)));
@@ -173,9 +168,9 @@ void LiveWireLwrpAudio::processCommand(RDMacro *cmd)
 
 void LiveWireLwrpAudio::nodeConnectedData(unsigned id)
 {
-  LogLine(RDConfig::LogInfo,QString().
-	  sprintf("connection established to LiveWire node at \"%s\"",
-		  (const char *)livewire_nodes[id]->hostname()));
+  rda->syslog(LOG_INFO,
+	      "connection established to LiveWire node at \"%s\"",
+	      (const char *)livewire_nodes[id]->hostname().toUtf8());
 }
 
 
@@ -184,36 +179,24 @@ void LiveWireLwrpAudio::sourceChangedData(unsigned id,RDLiveWireSource *src)
   QString sql;
   RDSqlQuery *q;
 
-  sql=QString().sprintf("delete from INPUTS where \
-                         (STATION_NAME=\"%s\")&&\
-                         (MATRIX=%d)&&\
-                         (NODE_HOSTNAME=\"%s\")&&\
-                         (NODE_TCP_PORT=%d)&&\
-                         (NODE_SLOT=%d)",
-			(const char *)livewire_stationname,
-			livewire_matrix,
-			(const char *)livewire_nodes[id]->hostname(),
-			livewire_nodes[id]->tcpPort(),
-			src->slotNumber());
+  sql=QString("delete from INPUTS where ")+
+    "(STATION_NAME=\""+RDEscapeString(livewire_stationname)+"\")&&"+
+    QString().sprintf("(MATRIX=%d)&&",livewire_matrix)+
+    "(NODE_HOSTNAME=\""+RDEscapeString(livewire_nodes[id]->hostname())+"\")&&"+
+    QString().sprintf("(NODE_TCP_PORT=%d)&&",livewire_nodes[id]->tcpPort())+
+    QString().sprintf("(NODE_SLOT=%d)",src->slotNumber());
   q=new RDSqlQuery(sql);
   delete q;
 
   if(src->rtpEnabled()) {
-    sql=QString().sprintf("insert into INPUTS set \
-                           STATION_NAME=\"%s\",\
-                           MATRIX=%d,\
-                           NODE_HOSTNAME=\"%s\",\
-                           NODE_TCP_PORT=%d,\
-                           NODE_SLOT=%d,\
-                           NAME=\"%s\",\
-                           NUMBER=%d",
-			  (const char *)livewire_stationname,
-			  livewire_matrix,
-			  (const char *)livewire_nodes[id]->hostname(),
-			  livewire_nodes[id]->tcpPort(),
-			  src->slotNumber(),
-			  (const char *)src->primaryName(),
-			  src->channelNumber());
+    sql=QString("insert into INPUTS set ")+
+      "STATION_NAME=\""+RDEscapeString(livewire_stationname)+"\","+
+      QString().sprintf("MATRIX=%d,",livewire_matrix)+
+      "NODE_HOSTNAME=\""+RDEscapeString(livewire_nodes[id]->hostname())+"\","+
+      QString().sprintf("NODE_TCP_PORT=%d,",livewire_nodes[id]->tcpPort())+
+      QString().sprintf("NODE_SLOT=%d,",src->slotNumber())+
+      "NAME=\""+RDEscapeString(src->primaryName())+"\","+
+      QString().sprintf("NUMBER=%d",src->channelNumber());
     q=new RDSqlQuery(sql);
     delete q;
   }
@@ -225,35 +208,24 @@ void LiveWireLwrpAudio::destinationChangedData(unsigned id,RDLiveWireDestination
   QString sql;
   RDSqlQuery *q;
 
-  sql=QString().sprintf("delete from OUTPUTS where \
-                         (STATION_NAME=\"%s\")&&\
-                         (MATRIX=%d)&&\
-                         (NODE_HOSTNAME=\"%s\")&&\
-                         (NODE_TCP_PORT=%d)&&\
-                         (NODE_SLOT=%d)",
-			(const char *)livewire_stationname,
-			livewire_matrix,
-			(const char *)livewire_nodes[id]->hostname(),
-			livewire_nodes[id]->tcpPort(),
-			dst->slotNumber());
+  sql=QString("delete from OUTPUTS where ")+
+    "(STATION_NAME=\""+RDEscapeString(livewire_stationname)+"\")&&"+
+    QString().sprintf("(MATRIX=%d)&&",livewire_matrix)+
+    "(NODE_HOSTNAME=\""+RDEscapeString(livewire_nodes[id]->hostname())+"\")&&"+
+    QString().sprintf("(NODE_TCP_PORT=%d)&&",livewire_nodes[id]->tcpPort())+
+    QString().sprintf("(NODE_SLOT=%d)",dst->slotNumber());
   q=new RDSqlQuery(sql);
   delete q;
 
-  sql=QString().sprintf("insert into OUTPUTS set \
-                         STATION_NAME=\"%s\",\
-                         MATRIX=%d,\
-                         NODE_HOSTNAME=\"%s\",\
-                         NODE_TCP_PORT=%d,\
-                         NODE_SLOT=%d,\
-                         NAME=\"%s\",\
-                         NUMBER=%d",
-			(const char *)livewire_stationname,
-			livewire_matrix,
-			(const char *)livewire_nodes[id]->hostname(),
-			livewire_nodes[id]->tcpPort(),
-			dst->slotNumber(),
-			(const char *)dst->primaryName(),
-			livewire_nodes[id]->baseOutput()+dst->slotNumber()-1);
+  sql=QString("insert into OUTPUTS set ")+
+    "STATION_NAME=\""+RDEscapeString(livewire_stationname)+"\","+
+    QString().sprintf("MATRIX=%d,",livewire_matrix)+
+    "NODE_HOSTNAME=\""+RDEscapeString(livewire_nodes[id]->hostname())+"\","+
+    QString().sprintf("NODE_TCP_PORT=%d,",livewire_nodes[id]->tcpPort())+
+    QString().sprintf("NODE_SLOT=%d,",dst->slotNumber())+
+    "NAME=\""+RDEscapeString(dst->primaryName())+"\","+
+    QString().sprintf("NUMBER=%d",
+		      livewire_nodes[id]->baseOutput()+dst->slotNumber()-1);
   q=new RDSqlQuery(sql);
   delete q;
 }
@@ -261,5 +233,5 @@ void LiveWireLwrpAudio::destinationChangedData(unsigned id,RDLiveWireDestination
 
 void LiveWireLwrpAudio::watchdogStateChangedData(unsigned id,const QString &msg)
 {
-  LogLine(RDConfig::LogNotice,msg);
+  rda->syslog(LOG_WARNING,msg);
 }
