@@ -1,9 +1,8 @@
 // sas64000gpi.cpp
 //
-// A Rivendell switcher driver for the SAS64000 connected via 
-//   a GPI-1600
+// A Rivendell switcher driver for the SAS64000 connected via a GPI-1600
 //
-//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -48,7 +47,7 @@ Sas64000Gpi::Sas64000Gpi(RDMatrix *matrix,QObject *parent)
     sas_device->setSpeed(tty->baudRate());
     sas_device->setWordLength(tty->dataBits());
     sas_device->setParity(tty->parity());
-    sas_device->open(QIODevice::Unbuffered|QIODevice::ReadWrite);
+    sas_device->open(QIODevice::Unbuffered|QIODevice::WriteOnly);
   }
   delete tty;
 
