@@ -2,7 +2,7 @@
 //
 // Rivendell web service portal -- CopyAudio service
 //
-//   (C) Copyright 2010,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2010-2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,12 +26,13 @@
 #include <errno.h>
 #include <unistd.h>
 
-#include <rdformpost.h>
-#include <rdweb.h>
-#include <rdcart.h>
+#include <rdapplication.h>
 #include <rdaudioconvert.h>
-#include <rdsettings.h>
+#include <rdcart.h>
 #include <rdconf.h>
+#include <rdformpost.h>
+#include <rdsettings.h>
+#include <rdweb.h>
 
 #include <rdxport.h>
 
@@ -61,10 +62,10 @@ void Xport::CopyAudio()
   //
   // Verify User Perms
   //
-  if(!xport_user->cartAuthorized(source_cartnum)) {
+  if(!rda->user()->cartAuthorized(source_cartnum)) {
     XmlExit("No such cart",404,"copyaudio.cpp",LINE_NUMBER);
   }
-  if(!xport_user->cartAuthorized(destination_cartnum)) {
+  if(!rda->user()->cartAuthorized(destination_cartnum)) {
     XmlExit("No such cart",404,"copyaudio.cpp",LINE_NUMBER);
   }
 
@@ -76,5 +77,7 @@ void Xport::CopyAudio()
 	  RDCut::pathName(destination_cartnum,destination_cutnum))!=0) {
     XmlExit(strerror(errno),400,"copyaudio.cpp",LINE_NUMBER);
   }
+  SendNotification(RDNotification::CartType,RDNotification::ModifyAction,
+		   QVariant(destination_cartnum));
   XmlExit("OK",200,"copyaudio.cpp",LINE_NUMBER);
 }
